/*

From: James Wadlow <Jwad@nb.net>
Newsgroups: comp.lang.clipper
Subject: Re: Barcode printing for Clipper Summer 87
Date: Wed, 25 Sep 1996 17:57:24 -0700
Organization: J-DOS Software (That Clipper Guy!)
Reply-To: Jwad@nb.net

Naseem F. Saab wrote:

> I am looking for freeware/shareware/commercial Barcode printing program or library to enhance an existing
> Clipper Summer 87 application. I have already tried Zac Catalog and the Oasis.

> Clipper 5.x products are not an option unless Summer 87 compatible Source Code is included.

> Requirements:
>  - Supports Code 39
>  - Supports LaserJet printers
>  - Supports Epson Dot Matrix 9 & 24 pin printers
>  - Control of positioning the barcode for two or three across Laser output

> Thank you in Advance.

here you go:

*/

func main ( text, text2, text3 )

local w1, uselazer := .f.
local num:=bcols:=3, brows:=2
*local text:=text2:=text3:=space(12)

text := if( text==NIL,space(12),padr(text,12))
text2 := if( text2==NIL,space(12),padr(text2,12))
text3 := if( text3==NIL,space(12),padr(text3,12))


initsup()

*cls('=B0','gr+/b')
w1 = makebox(6,10,15,69,c_popcol)

@ 7,11 say 'Using Laser Printer ?' get uselazer
@ 8,11 say 'Barcode Data        ?' get text
@ 9,11 say 'Barcode Text2 (Opt) ?' get text2
@10,11 say 'Barcode Text3 (Opt) ?' get text3

@12,11 say 'Height of Barcode   ?' get brows

@13,11 say 'Number To Print     ?' get num
@14,11 say 'Number Across       ?' get bcols
read
unbox( w1 )
if lastkey()=27
   return NIL
endif

text  := ltrim(trim(text ))     && kill any extra spaces
text2 := ltrim(trim(text2))
text3 := ltrim(trim(text3))

if uselazer
   set printer to lpt2
endif

printbar( uselazer, trim(text), num, brows, bcols, trim(text2), trim(text3) )
set printer to lpt1
return NIL


***************************************
*    FUNCTION: PrintBar
* DESCRIPTION: Creates code-39 bar code on laser/epson compatible printer
*  PARAMETERS:
*     UseLaser (Logical)   is printer a laser printer?
*      BarCode (Character) text to convert to barcode
*       [BCnt] (Number)    how many barcodes to print ?
*       [LCnt] (Number)    how many lines high is each barcode ?
*       [CCnt] (Number)    how many barcodes to print across page ?
*       [Msg1] (Character) optional text line 1
*       [Msg2] (Character) optional text line 2
***************************************
func PrintBar                  &&( UseLaser, Barcode, lcnt, Msg1, Msg2 )
param UseLaser, Barcode, bcnt, lcnt, Ccnt, Msg1, Msg2
local X, Y, Z, accros, E1, E2, O1, O2, N1, N2, cols, leng,rww,cll
local preamble, postamble, bar[126]

**** create default values
bcnt := if( bcnt = NIL, 1, bcnt )       && how many
lcnt := if( lcnt = NIL, 2, lcnt )       && how many rows high
ccnt := if( ccnt = NIL, 1, ccnt )       && how many rows across
msg1 := if( msg1 = NIL,'', msg1 )       && option text 1
msg2 := if( msg2 = NIL,'', msg2 )       && option text 2

leng = max(max(len(trim(msg1)),len(trim(msg2))),12)

***************** CALC TOTAL NUMBER OF LABELS TO PRINT
bcnt := int(bcnt/ccnt)+;
     IF( (bcnt/ccnt)-int(bcnt/ccnt) # 0,1,0)

initbar( UseLaser, @bar, @preamble, @postamble )

if !UseLaser          &&    * printer must be turned ON and set to correct printer
   cols := len(PreAmble)      && calculate N1 and N2 values for dot graphics command
   E1   := cols % 256
   E2   := INT(cols/256)

   cols := len(PostAmble)
   O1   := cols % 256
   O2   := INT(cols/256)
endif

pon()                   && printer on, console off

for Z = 1 to bcnt       && number of barcode rows to print

   if UseLaser          &&    * printer must be turned ON and set to correct printer

      ***** print barcode
      for X = 1 to Lcnt             && number of rows high
         for accros = 1 to Ccnt     && number of barcode to print across page

            ? space(3) + Preamble
            for Y = 1 to len(Barcode)
               ?? BAR[ asc(substr(Barcode, Y, 1)) ]
               ?? chr(27)+"*p+"+transform(3,'99')+"X"
            next
            ?? Postamble

            if X = 1
               ?? space(3) + padr(Msg1,12)
            else
               ?? space(3) + padr(Msg2,12)
            endif

            if ccnt > 1             && space between barcodes
               *               ?? space(10)
            endif
         next
      next

   else                             && use Epson/IBM method

      rww:=prow()
      cll:=pcol()

      ? chr(27)+chr(51)+chr(2)      && set printer to 2/216 lines per inch Line Feed

      setprc(rww,cll)

      ***** print barcode
      for X = 1 to lcnt             && number of lines of bars
         for accros = 1 to Ccnt     && number of barcode to print across page

            rww:=prow()
            cll:=pcol()

            ?? chr(27) + "L" + chr(30) + chr(0) +
            replicate(CHR(0),30)         && print a few blanks to separate the left margin
            ?? chr(27) + "L" + chr(E1) + chr(E2) + PreAmble

            setprc(rww,cll)

            for Y = 1 to len(Barcode)                  && for each character
               cols := len( BAR[ asc(substr(Barcode, Y, 1)) ] ) + 2         && include a Narrow Space between characters
               N1   := cols % 256
               N2   := INT(cols/256)
               ?? chr(27) + "L" + chr(N1) + chr(N2) + BAR[ asc(substr(Barcode, Y, 1)) ] + chr(0) + chr(0)
            next
            rww:=prow()
            cll:=pcol()

            ?? chr(27) + "L" + chr(O1) + chr(O2) + PostAmble
            setprc(rww,cll)

            if X = 1
               ?? space(3) + padr(Msg1,12)
            elseif X = 2            && put a space between them
               ?? space(3) + padr(Msg2,12)
            endif

            if ccnt > 1             && space between barcodes
               *               ?? space(10)
               ?? space(3)
            endif
         next

         rww:=prow()
         cll:=pcol()

         ?? chr(27)+chr(74)+chr(24)+chr(13)         && perform 23 * 2/216 line feeds
         setprc(rww,cll)

      next

      rww:=prow()
      cll:=pcol()

      ?? chr(27) + chr(50)                      && set printer to 6 lpi, 10cpi
      setprc(rww,cll)

   endif

   ************************* print the barcode text
   for accros = 1 to Ccnt                                  && number of barcode to print across page
      ?? space((len(Barcode) / 2) + 3) + Barcode    && 3rd line (1/2 inch)
      if ccnt > 1             && space between barcodes
         ?? space(36)
      endif
   next

   ?                                             && line between barcodes

next
con()                   && console on, printer off

return NIL


***************************************
*    FUNCTION: InitBar
* DESCRIPTION: Creates code-39 bar code variables
*  PARAMETERS:
*     UseLaser (Logical)   is printer a laser printer?
*          Bar (Array)     array holding character definitions
*     Preamble (Character) start-up codes
*    Postamble (Character) ending codes
***************************************
func initbar( UseLaser, bar, preamble, postamble )

local NB, WB, NS, WS, small_bar, wide_bar, start_code, end_code

*NS = code for narrow space ( NO pins, 2 times )
*WS = code for wide   space ( NO pins, 4 times )
*NB = code for narrow   bar (ALL pins, 1 times )
*WB = code for wide     bar (ALL pins, 3 times )
*Start_Code = Adjust cursor position to start at top of line
*  End_Code = Adjust cursor position to return to bottom of line

if UseLaser        && Setup Laser Printer (HP)
   Small_bar = 3                             && points wide
   Wide_bar = round(Small_Bar * 2.25, 0)     && approx. 7 points

   NS = chr(27)+"*p+"+transform(small_bar,'99')+"X"
   WS = chr(27)+"*p+"+transform(wide_bar,'99')+"X"
   NB = chr(27)+"*c"+transform(small_bar,'99')+"a"+ltrim(rtrim(str(1*50)))+"b0P"+chr(27)+"*p+"+transform(small_bar,'99')+"X"
   WB = chr(27)+"*c"+transform(wide_bar,'99')+"a"+ltrim(rtrim(str(1*50)))+"b0P"+chr(27)+"*p+"+transform(wide_bar,'99')+"X"

   Start_Code = chr(27)+"*p-50Y"      && move UP (-) 50/300th (1/6) of an inch
   End_Code = chr(27)+"*p+50Y"        && move Down (+) 50/300th (1/6) of an inch

else                 && define Epson bars and spaces
   NS = chr(0) + chr(0)                        && NO pins, 2 times
   WS = chr(0) + chr(0) + chr(0) + chr(0)      && NO pins, 4 times
   NB = chr(255)                               && ALL pins, 1 time
   WB = chr(255) + chr(255) + chr(255)         && ALL pins, 3 times

   Start_Code = ""
   End_Code = ""

endif

* Define the Codes 3 of 9 in terms of nb, wb, ns and ws
BAR[01] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + WB+NS+NB+NS+NB+WS+NB+NS+WB
BAR[02] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + NB+NS+WB+NS+NB+WS+NB+NS+WB
BAR[03] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + WB+NS+WB+NS+NB+WS+NB+NS+NB
BAR[04] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + NB+NS+NB+NS+WB+WS+NB+NS+WB
BAR[05] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + WB+NS+NB+NS+WB+WS+NB+NS+NB
BAR[06] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + NB+NS+WB+NS+WB+WS+NB+NS+NB
BAR[07] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + NB+NS+NB+NS+NB+WS+WB+NS+WB
BAR[08] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + WB+NS+NB+NS+NB+WS+WB+NS+NB
BAR[09] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + NB+NS+WB+NS+NB+WS+WB+NS+NB
BAR[10] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + NB+NS+NB+NS+WB+WS+WB+NS+NB
BAR[11] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + WB+NS+NB+NS+NB+NS+NB+WS+WB
BAR[12] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + NB+NS+WB+NS+NB+NS+NB+WS+WB
BAR[13] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + WB+NS+WB+NS+NB+NS+NB+WS+NB
BAR[14] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + NB+NS+NB+NS+WB+NS+NB+WS+WB
BAR[15] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + WB+NS+NB+NS+WB+NS+NB+WS+NB
BAR[16] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + NB+NS+WB+NS+WB+NS+NB+WS+NB
BAR[17] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + NB+NS+NB+NS+NB+NS+WB+WS+WB
BAR[18] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + WB+NS+NB+NS+NB+NS+WB+WS+NB
BAR[19] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + NB+NS+WB+NS+NB+NS+WB+WS+NB
BAR[20] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + NB+NS+NB+NS+WB+NS+WB+WS+NB
BAR[21] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + WB+WS+NB+NS+NB+NS+NB+NS+WB
BAR[22] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + NB+WS+WB+NS+NB+NS+NB+NS+WB
BAR[23] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + WB+WS+WB+NS+NB+NS+NB+NS+NB
BAR[24] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + NB+WS+NB+NS+WB+NS+NB+NS+WB
BAR[25] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + WB+WS+NB+NS+WB+NS+NB+NS+NB
BAR[26] = NB+WS+NB+WS+NB+WS+NB+NS+NB + NS + NB+WS+WB+NS+WB+NS+NB+NS+NB
BAR[27] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + WB+NS+NB+NS+NB+WS+NB+NS+WB
BAR[28] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + NB+NS+WB+NS+NB+WS+NB+NS+WB
BAR[29] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + WB+NS+WB+NS+NB+WS+NB+NS+NB
BAR[30] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + NB+NS+NB+NS+WB+WS+NB+NS+WB
BAR[31] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + WB+NS+NB+NS+WB+WS+NB+NS+NB

BAR[32] = NB+WS+WB+NS+NB+NS+WB+NS+NB       && " " SPACE
BAR[33] = NB+WS+NB+WS+NB+NS+NB+WS+NB + NS + WB+NS+NB+NS+NB+WS+NB+NS+WB    && "!"
BAR[34] = NB+WS+NB+WS+NB+NS+NB+WS+NB + NS + NB+NS+WB+NS+NB+WS+NB+NS+WB    && """
BAR[35] = NB+WS+NB+WS+NB+NS+NB+WS+NB + NS + WB+NS+WB+NS+NB+WS+NB+NS+NB    && "#"
BAR[36] = NB+WS+NB+WS+NB+NS+NB+WS+NB + NS + NB+NS+NB+NS+WB+WS+NB+NS+WB    && "$"
BAR[37] = NB+WS+NB+WS+NB+NS+NB+WS+NB + NS + WB+NS+NB+NS+WB+WS+NB+NS+NB    && "%"
BAR[38] = NB+WS+NB+WS+NB+NS+NB+WS+NB + NS + NB+NS+WB+NS+WB+WS+NB+NS+NB    && "&"
BAR[39] = NB+WS+NB+WS+NB+NS+NB+WS+NB + NS + NB+NS+NB+NS+NB+WS+WB+NS+WB    && "'"
BAR[40] = NB+WS+NB+WS+NB+NS+NB+WS+NB + NS + WB+NS+NB+NS+NB+WS+WB+NS+NB    && "("
BAR[41] = NB+WS+NB+WS+NB+NS+NB+WS+NB + NS + NB+NS+WB+NS+NB+WS+WB+NS+NB    && ")"
BAR[42] = NB+WS+NB+WS+NB+NS+NB+WS+NB + NS + NB+NS+NB+NS+WB+WS+WB+NS+NB    && "*"
BAR[43] = NB+WS+NB+WS+NB+NS+NB+WS+NB + NS + WB+NS+NB+NS+NB+NS+NB+WS+WB    && "+"
BAR[44] = NB+WS+NB+WS+NB+NS+NB+WS+NB + NS + NB+NS+WB+NS+NB+NS+NB+WS+WB    && ","
BAR[45] = NB+WS+NB+NS+NB+NS+WB+NS+WB       && "-"
BAR[46] = WB+WS+NB+NS+NB+NS+WB+NS+NB       && ".".
BAR[47] = NB+WS+NB+WS+NB+NS+NB+WS+NB + NS + WB+NS+NB+NS+WB+NS+NB+WS+NB      && "/"

BAR[48] = NB+NS+NB+WS+WB+NS+WB+NS+NB       && "0"
BAR[49] = WB+NS+NB+WS+NB+NS+NB+NS+WB       && "1"
BAR[50] = NB+NS+WB+WS+NB+NS+NB+NS+WB       && "2"
BAR[51] = WB+NS+WB+WS+NB+NS+NB+NS+NB       && "3"
BAR[52] = NB+NS+NB+WS+WB+NS+NB+NS+WB       && "4"
BAR[53] = WB+NS+NB+WS+WB+NS+NB+NS+NB       && "5"
BAR[54] = NB+NS+WB+WS+WB+NS+NB+NS+NB       && "6"
BAR[55] = NB+NS+NB+WS+NB+NS+WB+NS+WB       && "7"
BAR[56] = WB+NS+NB+WS+NB+NS+WB+NS+NB       && "8"
BAR[57] = NB+NS+WB+WS+NB+NS+WB+NS+NB       && "9"

BAR[58] = NB+WS+NB+WS+NB+NS+NB+WS+NB + NS + NB+WS+WB+NS+WB+NS+NB+NS+NB     && ":"
BAR[59] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + NB+NS+WB+NS+WB+WS+NB+NS+NB     && ";"
BAR[60] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + NB+NS+NB+NS+NB+WS+WB+NS+WB     && "<"
BAR[61] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + WB+NS+NB+NS+NB+WS+WB+NS+NB     && "="
BAR[62] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + NB+NS+WB+NS+NB+WS+WB+NS+NB     && ">"
BAR[63] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + NB+NS+NB+NS+WB+WS+WB+NS+NB     && "?"
BAR[64] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + NB+WS+WB+NS+NB+NS+NB+NS+WB     && "@"

BAR[65] = WB+NS+NB+NS+NB+WS+NB+NS+WB       && "A"
BAR[66] = NB+NS+WB+NS+NB+WS+NB+NS+WB       && "B"
BAR[67] = WB+NS+WB+NS+NB+WS+NB+NS+NB       && "C"
BAR[68] = NB+NS+NB+NS+WB+WS+NB+NS+WB       && "D"
BAR[69] = WB+NS+NB+NS+WB+WS+NB+NS+NB       && "E"
BAR[70] = NB+NS+WB+NS+WB+WS+NB+NS+NB       && "F"
BAR[71] = NB+NS+NB+NS+NB+WS+WB+NS+WB       && "G"
BAR[72] = WB+NS+NB+NS+NB+WS+WB+NS+NB       && "H"
BAR[73] = NB+NS+WB+NS+NB+WS+WB+NS+NB       && "I"
BAR[74] = NB+NS+NB+NS+WB+WS+WB+NS+NB       && "J"
BAR[75] = WB+NS+NB+NS+NB+NS+NB+WS+WB       && "K"
BAR[76] = NB+NS+WB+NS+NB+NS+NB+WS+WB       && "L"
BAR[77] = WB+NS+WB+NS+NB+NS+NB+WS+NB       && "M"
BAR[78] = NB+NS+NB+NS+WB+NS+NB+WS+WB       && "N"
BAR[79] = WB+NS+NB+NS+WB+NS+NB+WS+NB       && "O"
BAR[80] = NB+NS+WB+NS+WB+NS+NB+WS+NB       && "P"
BAR[81] = NB+NS+NB+NS+NB+NS+WB+WS+WB       && "Q"
BAR[82] = WB+NS+NB+NS+NB+NS+WB+WS+NB       && "R"
BAR[83] = NB+NS+WB+NS+NB+NS+WB+WS+NB       && "S"
BAR[84] = NB+NS+NB+NS+WB+NS+WB+WS+NB       && "T"
BAR[85] = WB+WS+NB+NS+NB+NS+NB+NS+WB       && "U"
BAR[86] = NB+WS+WB+NS+NB+NS+NB+NS+WB       && "V"
BAR[87] = WB+WS+WB+NS+NB+NS+NB+NS+NB       && "W"
BAR[88] = NB+WS+NB+NS+WB+NS+NB+NS+WB       && "X"
BAR[89] = WB+WS+NB+NS+WB+NS+NB+NS+NB       && "Y"
BAR[90] = NB+WS+WB+NS+WB+NS+NB+NS+NB       && "Z"

BAR[91] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + WB+NS+NB+NS+NB+NS+NB+WS+WB    && "]"
BAR[92] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + NB+NS+WB+NS+NB+NS+NB+WS+WB    && "\"
BAR[93] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + WB+NS+WB+NS+NB+NS+NB+WS+NB    && "["
BAR[94] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + NB+NS+NB+NS+WB+NS+NB+WS+WB    && "^"
BAR[95] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + WB+NS+NB+NS+WB+NS+NB+WS+NB    && "_"
BAR[96] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + WB+WS+WB+NS+NB+NS+NB+NS+NB    && "`"

BAR[97] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + WB+NS+NB+NS+NB+WS+NB+NS+WB     && "a"
BAR[98] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + NB+NS+WB+NS+NB+WS+NB+NS+WB     && "b"
BAR[99] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + WB+NS+WB+NS+NB+WS+NB+NS+NB     && "c"
BAR[100] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + NB+NS+NB+NS+WB+WS+NB+NS+WB     && "d"
BAR[101] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + WB+NS+NB+NS+WB+WS+NB+NS+NB     && "e"
BAR[102] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + NB+NS+WB+NS+WB+WS+NB+NS+NB     && "f"
BAR[103] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + NB+NS+NB+NS+NB+WS+WB+NS+WB     && "g"
BAR[104] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + WB+NS+NB+NS+NB+WS+WB+NS+NB     && "h"
BAR[105] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + NB+NS+WB+NS+NB+WS+WB+NS+NB     && "i"
BAR[106] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + NB+NS+NB+NS+WB+WS+WB+NS+NB     && "j"
BAR[107] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + WB+NS+NB+NS+NB+NS+NB+WS+WB     && "k"
BAR[108] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + NB+NS+WB+NS+NB+NS+NB+WS+WB     && "l"
BAR[109] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + WB+NS+WB+NS+NB+NS+NB+WS+NB     && "m"
BAR[110] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + NB+NS+NB+NS+WB+NS+NB+WS+WB     && "n"
BAR[111] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + WB+NS+NB+NS+WB+NS+NB+WS+NB     && "o"
BAR[112] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + NB+NS+WB+NS+WB+NS+NB+WS+NB     && "p"
BAR[113] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + NB+NS+NB+NS+NB+NS+WB+WS+WB     && "q"
BAR[114] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + WB+NS+NB+NS+NB+NS+WB+WS+NB     && "r"
BAR[115] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + NB+NS+WB+NS+NB+NS+WB+WS+NB     && "s"
BAR[116] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + NB+NS+NB+NS+WB+NS+WB+WS+NB     && "t"
BAR[117] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + WB+WS+NB+NS+NB+NS+NB+NS+WB     && "u"
BAR[118] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + NB+WS+WB+NS+NB+NS+NB+NS+WB     && "v"
BAR[119] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + WB+WS+WB+NS+NB+NS+NB+NS+NB     && "w"
BAR[120] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + NB+WS+NB+NS+WB+NS+NB+NS+WB     && "x"
BAR[121] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + WB+WS+NB+NS+WB+NS+NB+NS+NB     && "y"
BAR[122] = NB+WS+NB+NS+NB+WS+NB+WS+NB + NS + NB+WS+WB+NS+WB+NS+NB+NS+NB     && "z"

BAR[123] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + NB+NS+WB+NS+WB+NS+NB+WS+NB     && "{"
BAR[124] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + NB+NS+NB+NS+NB+NS+WB+WS+WB     && "|"
BAR[125] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + WB+NS+NB+NS+NB+NS+WB+WS+NB     && "}"
BAR[126] = NB+NS+NB+WS+NB+WS+NB+WS+NB + NS + NB+NS+WB+NS+NB+NS+WB+WS+NB     && "~"

Preamble = Start_Code + NB+WS+NB+NS+WB+NS+WB+NS+NB + NS
Postamble = NB+WS+NB+NS+WB+NS+WB+NS+NB + End_Code

return ''

